Learn R Programming

PL94171 (version 1.2.1)

PL94171-package: PL94171: Tabulate P.L. 94-171 Redistricting Data Summary Files

Description

logo

Tools to process legacy format summary redistricting data files produced by the United States Census Bureau pursuant to P.L. 94-171. These files are generally available earlier but are difficult to work with as-is.

Arguments

Author

Maintainer: Cory McCartan mccartan@psu.edu

Authors:

See Also