powered by
Downloads crosswalks from https://www.census.gov/geographies/reference-files/time-series/geo/relationship-files.html. Adjusts land overlap area to ensure weights sum to 1.
pl_crosswalk(abbr, from_year = 2010L, to_year = from_year + 10L)
A tibble, with two sets of GEOIDs and overlap information.
the state to download the crosswalk for.
the year with the blocks that the data is currently tabulated with respect to.
the year with the blocks that the data should be tabulated into.
if (FALSE) { # Takes a bit of time to run pl_crosswalk("RI", 2010, 2020) }
Run the code above in your browser using DataLab