Learn R Programming

PL94171 (version 1.2.1)

pl_get_baf: Download 2020 Block Assignment Files for a State

Description

[Experimental] From the Census: "The Block Assignment Files (BAFs) are among the geographic products that the Census Bureau provides to states and other data users containing the small area census data necessary for legislative redistricting. The BAFs contain Census tabulation block codes and geographic area codes for a specific geographic entity type."

Usage

pl_get_baf(abbr, geographies = NULL, cache_to = NULL, refresh = FALSE)

Value

A list of data frames, one for each available BAF geography.

Arguments

abbr

the state abbreviation to get the BAF for

geographies

the geographies to get. Defaults to all available.

cache_to

the file name, if any, to cache the results to (as an RDS). If a file exists and refresh=FALSE, will read BAF from this file.

refresh

if TRUE, force a re-download of the BAF data.

Examples

Run this code
pl_get_baf("RI")
pl_get_baf("RI", "VTD")

Run the code above in your browser using DataLab