powered by
Downloads block geography and merges with the cleaned PL 94-171 file.
pl_tidy_shp(abbr, path, year = 2020, type = c("blocks", "vtds"), ...)
an sf object with demographic and shapefile information for the state.
sf
The state to make the shapefile for
The path to the PL files, as in pl_read()
pl_read()
The year to download the block geography for. Should match the year of the PL files.
If "blocks", make a Census block shapefile; if "vtds" make a VTD shapefile.
"blocks"
"vtds"
passed on to dplyr::filter(); use to subset to a certain county, for example.
dplyr::filter()
# \donttest{ pl_ex_path <- system.file("extdata/ri2018_2020Style.pl", package = "PL94171") pl_tidy_shp("RI", pl_ex_path) # }
Run the code above in your browser using DataLab